==> 0.0.13.tar.gz: lib/renderer/stage.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/scheduler.dart';
import 'package:flutter/widgets.dart';

import '../extensions/vector2.dart';
import '../extensions/offset.dart';
import '../widgets/stage_render_box.dart';
import 'renderer.dart';

abstract class Stage extends Renderer {
  StageRenderBox? _renderBox;
  BuildContext? get buildContext => _renderBox?.buildContext;
  bool get isAttached => _renderBox != null;

  final Vector2 _size = Vector2.zero();
  Vector2 get size => _size;

  @override
  @mustCallSuper
  void onCanvasResize(Vector2 canvasSize) {
    _size.setFrom(canvasSize);
    super.onCanvasResize(canvasSize);
  }

  @nonVirtual
  void attach(PipelineOwner owner, StageRenderBox renderBox) {
    if (isAttached) {
      throw UnsupportedError('Call attach multiple times');
    }
    _renderBox = renderBox;
    onAttach();
  }

  void onAttach() {}

  @nonVirtual
  void detach() {
    if (_renderBox == null) return;

    _renderBox = null;
    onDetach();
  }

  void onDetach() {}

  @override
  @mustCallSuper
  void tick({bool needsPaint = true}) {
    super.tick(needsPaint: needsPaint);
    if (needsPaint) {
      _renderBox?.refresh();
    }
  }

  @override
  @mustCallSuper
  void tickChildren({bool fromChild = false, bool needsPaint = true}) {
    super.tickChildren(fromChild: fromChild, needsPaint: needsPaint);
    if (needsPaint) {
      _renderBox?.refresh();
    }
  }

  void onTimingsCallback(List<FrameTiming> timings) {}

  Vector2 convertGlobalToLocalCoordinate(Vector2 point) {
    return isAttached ? _renderBox!.globalToLocal(point.toOffset()).toVector2() : point.clone();
  }

  Vector2 convertLocalToGlobalCoordinate(Vector2 point) {
    return isAttached ? _renderBox!.localToGlobal(point.toOffset()).toVector2() : point.clone();
  }
}

==> 0.0.14.tar.gz: lib/renderer/stage.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/scheduler.dart';
import 'package:flutter/widgets.dart';

import '../extensions/vector2.dart';
import '../extensions/offset.dart';
import '../widgets/stage_render_box.dart';
import 'renderer.dart';

abstract class Stage extends Renderer {
  StageRenderBox? _renderBox;
  BuildContext? get buildContext => _renderBox?.buildContext;
  bool get isAttached => _renderBox != null;

  final Vector2 _size = Vector2.zero();
  Vector2 get size => _size;

  @override
  @mustCallSuper
  void onCanvasResize(Vector2 canvasSize) {
    _size.setFrom(canvasSize);
    super.onCanvasResize(canvasSize);
  }

  @nonVirtual
  void attach(PipelineOwner owner, StageRenderBox renderBox) {
    if (isAttached) {
      throw UnsupportedError('Call attach multiple times');
    }
    _renderBox = renderBox;
    onAttach();
  }

  void onAttach() {}

  @nonVirtual
  void detach() {
    if (_renderBox == null) return;

    _renderBox = null;
    onDetach();
  }

  void onDetach() {}

  @override
  @mustCallSuper
  void tick() {
    super.tick();
    if (enableTickToParent) {
      _renderBox?.refresh();
    }
  }

  @override
  @mustCallSuper
  void tickChildren({bool fromChild = false}) {
    super.tickChildren(fromChild: fromChild);
    if (enableTickToParent) {
      _renderBox?.refresh();
    }
  }

  void onTimingsCallback(List<FrameTiming> timings) {}

  Vector2 convertGlobalToLocalCoordinate(Vector2 point) {
    return isAttached ? _renderBox!.globalToLocal(point.toOffset()).toVector2() : point.clone();
  }

  Vector2 convertLocalToGlobalCoordinate(Vector2 point) {
    return isAttached ? _renderBox!.localToGlobal(point.toOffset()).toVector2() : point.clone();
  }
}
